@@ -17,7 +17,7 @@ def compileLibrary():
     try:
         currentDir = os.getcwd()
         os.chdir(os.path.abspath(os.path.join(
-            os.path.dirname(__file__), '')) + "/go")
+            os.path.dirname(__file__), '..')) + "/go")
         subprocess.check_output(
             ["go", "build", "-buildmode=c-shared", "-o", "./compiled/library.so"])
         os.chdir(currentDir)
@@ -28,12 +28,12 @@ def compileLibrary():
 
 def loadLibrary():
     currentDir = (os.path.abspath(
-        os.path.join(os.path.dirname(__file__),)))
+        os.path.join(os.path.dirname(__file__), '..')))
     if not os.path.exists(currentDir + "/go/compiled/library.so"):
         print("Library not found, compiling...")
         compileLibrary()
     # get location of current file
     path = os.path.abspath(os.path.join(
-        os.path.dirname(__file__),)) + "/go/compiled/library.so"
+        os.path.dirname(__file__), '..')) + "/go/compiled/library.so"
     library = ctypes.cdll.LoadLibrary(path)
     return library
